========
Analysis
========

The ``Analysis`` object defines the ``log_likelihood_function`` of your model-fitting problem.

It acts as an interface between the data, model and the non-linear search.

**Examples / Tutorials:**

- `readthedocs: example using Analysis object <https://pyautofit.readthedocs.io/en/latest/overview/model_fit.html>`_.
- `autofit_workspace: simple tutorial <https://github.com/Jammy2211/autofit_workspace/blob/release/notebooks/overview/simple/fit.ipynb>`_
- `autofit_workspace: complex tutorial <https://github.com/Jammy2211/autofit_workspace/blob/release/notebooks/overview/complex/fit.ipynb>`_
- `HowToFit: introduction chapter (detailed step-by-step examples) <https://pyautofit.readthedocs.io/en/latest/howtofit/chapter_1_introduction.html>`_

--------
Analysis
--------

.. currentmodule:: autofit

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:

   Analysis